# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_client.model.audiences_sub_object import AudiencesSubObject
from openapi_client.model.campaign_clone_query import CampaignCloneQuery
from openapi_client.model.campaign_clone_query_resource_object import CampaignCloneQueryResourceObject
from openapi_client.model.campaign_clone_query_resource_object_attributes import CampaignCloneQueryResourceObjectAttributes
from openapi_client.model.campaign_create_query import CampaignCreateQuery
from openapi_client.model.campaign_create_query_resource_object import CampaignCreateQueryResourceObject
from openapi_client.model.campaign_create_query_resource_object_attributes import CampaignCreateQueryResourceObjectAttributes
from openapi_client.model.campaign_enum import CampaignEnum
from openapi_client.model.campaign_message_assign_template_query import CampaignMessageAssignTemplateQuery
from openapi_client.model.campaign_message_assign_template_query_resource_object import CampaignMessageAssignTemplateQueryResourceObject
from openapi_client.model.campaign_message_assign_template_query_resource_object_attributes import CampaignMessageAssignTemplateQueryResourceObjectAttributes
from openapi_client.model.campaign_message_enum import CampaignMessageEnum
from openapi_client.model.campaign_message_partial_update_query import CampaignMessagePartialUpdateQuery
from openapi_client.model.campaign_message_partial_update_query_resource_object import CampaignMessagePartialUpdateQueryResourceObject
from openapi_client.model.campaign_message_partial_update_query_resource_object_attributes import CampaignMessagePartialUpdateQueryResourceObjectAttributes
from openapi_client.model.campaign_partial_update_query import CampaignPartialUpdateQuery
from openapi_client.model.campaign_partial_update_query_resource_object import CampaignPartialUpdateQueryResourceObject
from openapi_client.model.campaign_partial_update_query_resource_object_attributes import CampaignPartialUpdateQueryResourceObjectAttributes
from openapi_client.model.campaign_recipient_estimation_job_create_query import CampaignRecipientEstimationJobCreateQuery
from openapi_client.model.campaign_recipient_estimation_job_create_query_resource_object import CampaignRecipientEstimationJobCreateQueryResourceObject
from openapi_client.model.campaign_recipient_estimation_job_create_query_resource_object_attributes import CampaignRecipientEstimationJobCreateQueryResourceObjectAttributes
from openapi_client.model.campaign_recipient_estimation_job_enum import CampaignRecipientEstimationJobEnum
from openapi_client.model.campaign_send_job_create_query import CampaignSendJobCreateQuery
from openapi_client.model.campaign_send_job_create_query_resource_object import CampaignSendJobCreateQueryResourceObject
from openapi_client.model.campaign_send_job_create_query_resource_object_attributes import CampaignSendJobCreateQueryResourceObjectAttributes
from openapi_client.model.campaign_send_job_enum import CampaignSendJobEnum
from openapi_client.model.campaign_send_job_partial_update_query import CampaignSendJobPartialUpdateQuery
from openapi_client.model.campaign_send_job_partial_update_query_resource_object import CampaignSendJobPartialUpdateQueryResourceObject
from openapi_client.model.campaign_send_job_partial_update_query_resource_object_attributes import CampaignSendJobPartialUpdateQueryResourceObjectAttributes
from openapi_client.model.catalog_category_bulk_create_job_enum import CatalogCategoryBulkCreateJobEnum
from openapi_client.model.catalog_category_bulk_delete_job_enum import CatalogCategoryBulkDeleteJobEnum
from openapi_client.model.catalog_category_bulk_update_job_enum import CatalogCategoryBulkUpdateJobEnum
from openapi_client.model.catalog_category_create_job_create_query import CatalogCategoryCreateJobCreateQuery
from openapi_client.model.catalog_category_create_job_create_query_resource_object import CatalogCategoryCreateJobCreateQueryResourceObject
from openapi_client.model.catalog_category_create_job_create_query_resource_object_attributes import CatalogCategoryCreateJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_category_create_query import CatalogCategoryCreateQuery
from openapi_client.model.catalog_category_create_query_resource_object import CatalogCategoryCreateQueryResourceObject
from openapi_client.model.catalog_category_create_query_resource_object_attributes import CatalogCategoryCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_category_delete_job_create_query import CatalogCategoryDeleteJobCreateQuery
from openapi_client.model.catalog_category_delete_job_create_query_resource_object import CatalogCategoryDeleteJobCreateQueryResourceObject
from openapi_client.model.catalog_category_delete_job_create_query_resource_object_attributes import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_category_delete_query_resource_object import CatalogCategoryDeleteQueryResourceObject
from openapi_client.model.catalog_category_enum import CatalogCategoryEnum
from openapi_client.model.catalog_category_item_op import CatalogCategoryItemOp
from openapi_client.model.catalog_category_update_job_create_query import CatalogCategoryUpdateJobCreateQuery
from openapi_client.model.catalog_category_update_job_create_query_resource_object import CatalogCategoryUpdateJobCreateQueryResourceObject
from openapi_client.model.catalog_category_update_job_create_query_resource_object_attributes import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_category_update_query import CatalogCategoryUpdateQuery
from openapi_client.model.catalog_category_update_query_resource_object import CatalogCategoryUpdateQueryResourceObject
from openapi_client.model.catalog_category_update_query_resource_object_attributes import CatalogCategoryUpdateQueryResourceObjectAttributes
from openapi_client.model.catalog_category_update_query_resource_object_relationships import CatalogCategoryUpdateQueryResourceObjectRelationships
from openapi_client.model.catalog_category_update_query_resource_object_relationships_items import CatalogCategoryUpdateQueryResourceObjectRelationshipsItems
from openapi_client.model.catalog_category_update_query_resource_object_relationships_items_data_inner import CatalogCategoryUpdateQueryResourceObjectRelationshipsItemsDataInner
from openapi_client.model.catalog_item_bulk_create_job_enum import CatalogItemBulkCreateJobEnum
from openapi_client.model.catalog_item_bulk_delete_job_enum import CatalogItemBulkDeleteJobEnum
from openapi_client.model.catalog_item_bulk_update_job_enum import CatalogItemBulkUpdateJobEnum
from openapi_client.model.catalog_item_category_op import CatalogItemCategoryOp
from openapi_client.model.catalog_item_category_op_data_inner import CatalogItemCategoryOpDataInner
from openapi_client.model.catalog_item_create_job_create_query import CatalogItemCreateJobCreateQuery
from openapi_client.model.catalog_item_create_job_create_query_resource_object import CatalogItemCreateJobCreateQueryResourceObject
from openapi_client.model.catalog_item_create_job_create_query_resource_object_attributes import CatalogItemCreateJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_item_create_query import CatalogItemCreateQuery
from openapi_client.model.catalog_item_create_query_resource_object import CatalogItemCreateQueryResourceObject
from openapi_client.model.catalog_item_create_query_resource_object_attributes import CatalogItemCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_item_create_query_resource_object_relationships import CatalogItemCreateQueryResourceObjectRelationships
from openapi_client.model.catalog_item_create_query_resource_object_relationships_categories import CatalogItemCreateQueryResourceObjectRelationshipsCategories
from openapi_client.model.catalog_item_delete_job_create_query import CatalogItemDeleteJobCreateQuery
from openapi_client.model.catalog_item_delete_job_create_query_resource_object import CatalogItemDeleteJobCreateQueryResourceObject
from openapi_client.model.catalog_item_delete_job_create_query_resource_object_attributes import CatalogItemDeleteJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_item_delete_query_resource_object import CatalogItemDeleteQueryResourceObject
from openapi_client.model.catalog_item_enum import CatalogItemEnum
from openapi_client.model.catalog_item_update_job_create_query import CatalogItemUpdateJobCreateQuery
from openapi_client.model.catalog_item_update_job_create_query_resource_object import CatalogItemUpdateJobCreateQueryResourceObject
from openapi_client.model.catalog_item_update_job_create_query_resource_object_attributes import CatalogItemUpdateJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_item_update_query import CatalogItemUpdateQuery
from openapi_client.model.catalog_item_update_query_resource_object import CatalogItemUpdateQueryResourceObject
from openapi_client.model.catalog_item_update_query_resource_object_attributes import CatalogItemUpdateQueryResourceObjectAttributes
from openapi_client.model.catalog_variant_bulk_create_job_enum import CatalogVariantBulkCreateJobEnum
from openapi_client.model.catalog_variant_bulk_delete_job_enum import CatalogVariantBulkDeleteJobEnum
from openapi_client.model.catalog_variant_bulk_update_job_enum import CatalogVariantBulkUpdateJobEnum
from openapi_client.model.catalog_variant_create_job_create_query import CatalogVariantCreateJobCreateQuery
from openapi_client.model.catalog_variant_create_job_create_query_resource_object import CatalogVariantCreateJobCreateQueryResourceObject
from openapi_client.model.catalog_variant_create_job_create_query_resource_object_attributes import CatalogVariantCreateJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_variant_create_query import CatalogVariantCreateQuery
from openapi_client.model.catalog_variant_create_query_resource_object import CatalogVariantCreateQueryResourceObject
from openapi_client.model.catalog_variant_create_query_resource_object_attributes import CatalogVariantCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_variant_delete_job_create_query import CatalogVariantDeleteJobCreateQuery
from openapi_client.model.catalog_variant_delete_job_create_query_resource_object import CatalogVariantDeleteJobCreateQueryResourceObject
from openapi_client.model.catalog_variant_delete_job_create_query_resource_object_attributes import CatalogVariantDeleteJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_variant_delete_query_resource_object import CatalogVariantDeleteQueryResourceObject
from openapi_client.model.catalog_variant_enum import CatalogVariantEnum
from openapi_client.model.catalog_variant_update_job_create_query import CatalogVariantUpdateJobCreateQuery
from openapi_client.model.catalog_variant_update_job_create_query_resource_object import CatalogVariantUpdateJobCreateQueryResourceObject
from openapi_client.model.catalog_variant_update_job_create_query_resource_object_attributes import CatalogVariantUpdateJobCreateQueryResourceObjectAttributes
from openapi_client.model.catalog_variant_update_query import CatalogVariantUpdateQuery
from openapi_client.model.catalog_variant_update_query_resource_object import CatalogVariantUpdateQueryResourceObject
from openapi_client.model.catalog_variant_update_query_resource_object_attributes import CatalogVariantUpdateQueryResourceObjectAttributes
from openapi_client.model.content_sub_object import ContentSubObject
from openapi_client.model.data_privacy_create_deletion_job_query import DataPrivacyCreateDeletionJobQuery
from openapi_client.model.data_privacy_create_deletion_job_query_resource_object import DataPrivacyCreateDeletionJobQueryResourceObject
from openapi_client.model.data_privacy_create_deletion_job_query_resource_object_attributes import DataPrivacyCreateDeletionJobQueryResourceObjectAttributes
from openapi_client.model.data_privacy_deletion_job_enum import DataPrivacyDeletionJobEnum
from openapi_client.model.event_create_query import EventCreateQuery
from openapi_client.model.event_create_query_resource_object import EventCreateQueryResourceObject
from openapi_client.model.event_create_query_resource_object_attributes import EventCreateQueryResourceObjectAttributes
from openapi_client.model.event_enum import EventEnum
from openapi_client.model.flow_enum import FlowEnum
from openapi_client.model.flow_update_query import FlowUpdateQuery
from openapi_client.model.flow_update_query_resource_object import FlowUpdateQueryResourceObject
from openapi_client.model.flow_update_query_resource_object_attributes import FlowUpdateQueryResourceObjectAttributes
from openapi_client.model.get_create_variants_jobs5_xx_response import GetCreateVariantsJobs5XXResponse
from openapi_client.model.get_create_variants_jobs5_xx_response_errors_inner import GetCreateVariantsJobs5XXResponseErrorsInner
from openapi_client.model.get_create_variants_jobs5_xx_response_errors_inner_source import GetCreateVariantsJobs5XXResponseErrorsInnerSource
from openapi_client.model.list_create_query import ListCreateQuery
from openapi_client.model.list_create_query_resource_object import ListCreateQueryResourceObject
from openapi_client.model.list_create_query_resource_object_attributes import ListCreateQueryResourceObjectAttributes
from openapi_client.model.list_enum import ListEnum
from openapi_client.model.list_members_add_query import ListMembersAddQuery
from openapi_client.model.list_members_add_query_data_inner import ListMembersAddQueryDataInner
from openapi_client.model.list_members_delete_query import ListMembersDeleteQuery
from openapi_client.model.list_partial_update_query import ListPartialUpdateQuery
from openapi_client.model.list_partial_update_query_resource_object import ListPartialUpdateQueryResourceObject
from openapi_client.model.metric_aggregate_enum import MetricAggregateEnum
from openapi_client.model.metric_aggregate_query import MetricAggregateQuery
from openapi_client.model.metric_aggregate_query_resource_object import MetricAggregateQueryResourceObject
from openapi_client.model.metric_aggregate_query_resource_object_attributes import MetricAggregateQueryResourceObjectAttributes
from openapi_client.model.metric_create_query import MetricCreateQuery
from openapi_client.model.profile_create_query import ProfileCreateQuery
from openapi_client.model.profile_create_query_resource_object import ProfileCreateQueryResourceObject
from openapi_client.model.profile_create_query_resource_object_attributes import ProfileCreateQueryResourceObjectAttributes
from openapi_client.model.profile_enum import ProfileEnum
from openapi_client.model.profile_location import ProfileLocation
from openapi_client.model.profile_location_latitude import ProfileLocationLatitude
from openapi_client.model.profile_location_longitude import ProfileLocationLongitude
from openapi_client.model.profile_partial_update_query import ProfilePartialUpdateQuery
from openapi_client.model.profile_partial_update_query_resource_object import ProfilePartialUpdateQueryResourceObject
from openapi_client.model.profile_partial_update_query_resource_object_attributes import ProfilePartialUpdateQueryResourceObjectAttributes
from openapi_client.model.profile_subscription_bulk_create_job_enum import ProfileSubscriptionBulkCreateJobEnum
from openapi_client.model.profile_suppression_bulk_create_job_enum import ProfileSuppressionBulkCreateJobEnum
from openapi_client.model.profile_unsubscription_bulk_create_job_enum import ProfileUnsubscriptionBulkCreateJobEnum
from openapi_client.model.profile_unsuppression_bulk_create_job_enum import ProfileUnsuppressionBulkCreateJobEnum
from openapi_client.model.sto_schedule_options import STOScheduleOptions
from openapi_client.model.segment_enum import SegmentEnum
from openapi_client.model.segment_partial_update_query import SegmentPartialUpdateQuery
from openapi_client.model.segment_partial_update_query_resource_object import SegmentPartialUpdateQueryResourceObject
from openapi_client.model.segment_partial_update_query_resource_object_attributes import SegmentPartialUpdateQueryResourceObjectAttributes
from openapi_client.model.send_options_sub_object import SendOptionsSubObject
from openapi_client.model.send_strategy_sub_object import SendStrategySubObject
from openapi_client.model.static_schedule_options import StaticScheduleOptions
from openapi_client.model.subscription import Subscription
from openapi_client.model.subscription_channels import SubscriptionChannels
from openapi_client.model.subscription_create_job_create_query import SubscriptionCreateJobCreateQuery
from openapi_client.model.subscription_create_job_create_query_resource_object import SubscriptionCreateJobCreateQueryResourceObject
from openapi_client.model.subscription_create_job_create_query_resource_object_attributes import SubscriptionCreateJobCreateQueryResourceObjectAttributes
from openapi_client.model.suppression import Suppression
from openapi_client.model.suppression_create_job_create_query import SuppressionCreateJobCreateQuery
from openapi_client.model.suppression_create_job_create_query_resource_object import SuppressionCreateJobCreateQueryResourceObject
from openapi_client.model.suppression_create_job_create_query_resource_object_attributes import SuppressionCreateJobCreateQueryResourceObjectAttributes
from openapi_client.model.tag_campaign_op import TagCampaignOp
from openapi_client.model.tag_campaign_op_data_inner import TagCampaignOpDataInner
from openapi_client.model.tag_create_query import TagCreateQuery
from openapi_client.model.tag_create_query_resource_object import TagCreateQueryResourceObject
from openapi_client.model.tag_create_query_resource_object_attributes import TagCreateQueryResourceObjectAttributes
from openapi_client.model.tag_enum import TagEnum
from openapi_client.model.tag_flow_op import TagFlowOp
from openapi_client.model.tag_flow_op_data_inner import TagFlowOpDataInner
from openapi_client.model.tag_group_create_query import TagGroupCreateQuery
from openapi_client.model.tag_group_create_query_resource_object import TagGroupCreateQueryResourceObject
from openapi_client.model.tag_group_create_query_resource_object_attributes import TagGroupCreateQueryResourceObjectAttributes
from openapi_client.model.tag_group_enum import TagGroupEnum
from openapi_client.model.tag_group_update_query import TagGroupUpdateQuery
from openapi_client.model.tag_group_update_query_resource_object import TagGroupUpdateQueryResourceObject
from openapi_client.model.tag_group_update_query_resource_object_attributes import TagGroupUpdateQueryResourceObjectAttributes
from openapi_client.model.tag_list_op import TagListOp
from openapi_client.model.tag_list_op_data_inner import TagListOpDataInner
from openapi_client.model.tag_segment_op import TagSegmentOp
from openapi_client.model.tag_segment_op_data_inner import TagSegmentOpDataInner
from openapi_client.model.tag_update_query import TagUpdateQuery
from openapi_client.model.tag_update_query_resource_object import TagUpdateQueryResourceObject
from openapi_client.model.tag_update_query_resource_object_attributes import TagUpdateQueryResourceObjectAttributes
from openapi_client.model.template_clone_query import TemplateCloneQuery
from openapi_client.model.template_clone_query_resource_object import TemplateCloneQueryResourceObject
from openapi_client.model.template_clone_query_resource_object_attributes import TemplateCloneQueryResourceObjectAttributes
from openapi_client.model.template_create_query import TemplateCreateQuery
from openapi_client.model.template_create_query_resource_object import TemplateCreateQueryResourceObject
from openapi_client.model.template_create_query_resource_object_attributes import TemplateCreateQueryResourceObjectAttributes
from openapi_client.model.template_enum import TemplateEnum
from openapi_client.model.template_render_query import TemplateRenderQuery
from openapi_client.model.template_render_query_resource_object import TemplateRenderQueryResourceObject
from openapi_client.model.template_render_query_resource_object_attributes import TemplateRenderQueryResourceObjectAttributes
from openapi_client.model.template_update_query import TemplateUpdateQuery
from openapi_client.model.template_update_query_resource_object import TemplateUpdateQueryResourceObject
from openapi_client.model.template_update_query_resource_object_attributes import TemplateUpdateQueryResourceObjectAttributes
from openapi_client.model.throttled_schedule_options import ThrottledScheduleOptions
from openapi_client.model.tracking_options_sub_object import TrackingOptionsSubObject
from openapi_client.model.utm_params_sub_object import UTMParamsSubObject
from openapi_client.model.unsubscription_create_job_create_query import UnsubscriptionCreateJobCreateQuery
from openapi_client.model.unsubscription_create_job_create_query_resource_object import UnsubscriptionCreateJobCreateQueryResourceObject
from openapi_client.model.unsubscription_create_job_create_query_resource_object_attributes import UnsubscriptionCreateJobCreateQueryResourceObjectAttributes
from openapi_client.model.unsuppression_create_job_create_query import UnsuppressionCreateJobCreateQuery
from openapi_client.model.unsuppression_create_job_create_query_resource_object import UnsuppressionCreateJobCreateQueryResourceObject
from openapi_client.model.unsuppression_create_job_create_query_resource_object_attributes import UnsuppressionCreateJobCreateQueryResourceObjectAttributes
